[−][src]Crate pop3_client
Structs
| Builder | A builder to create a |
| Client | The key structure for the crate, delineating capabilities of the POP3 client as per the protocol RFC |
Type Definitions
| Result |
| Builder | A builder to create a |
| Client | The key structure for the crate, delineating capabilities of the POP3 client as per the protocol RFC |
| Result |