[−][src]Struct pop3_client::Builder
A builder to create a Client with a connection.
As it is possible to create the Client without using Builder, we recommend to only use in when you with to define a custom ClientConfig for the TLS connection.
Methods
impl Builder[src]
pub fn connect(&mut self, host: &str, port: u16) -> Result<Client>[src]
Vanilla (no-tls) connection to the designated host and port
Example
let client = Builder::default().connect("my.host.com", 110)?;
Errors
The errors are defined by Client::connect() method.